;;; DO NOT MODIFY THIS FILE
(if (featurep 'igrep-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "igrep/_pkg.el")

(package-provide 'igrep :version 1.01 :type 'regular)

;;;***

;;;### (autoloads (dired-do-igrep-find dired-do-igrep igrep-find-define igrep-find igrep-define igrep igrep-insinuate) "igrep" "igrep/igrep.el")

(autoload 'igrep-insinuate "igrep" "\
Replace the `grep' functions with `igrep'." nil nil)

(autoload 'igrep "igrep" "\
*Run `grep` PROGRAM to match EXPRESSION in FILES.
The output is displayed in the *igrep* buffer, which \\[next-error] and
\\[compile-goto-error] parse to find each line of matched text.

PROGRAM may be nil, in which case it defaults to `igrep-program'.

EXPRESSION is automatically delimited by `igrep-expression-quote-char'.

FILES is either a file name pattern (expanded by the shell named by
`shell-file-name') or a list of file name patterns.

Optional OPTIONS is also passed to PROGRAM; it defaults to `igrep-options'.

If a prefix argument (\\[universal-argument]) is given when called interactively,
or if `igrep-read-options' is set, OPTIONS is read from the minibuffer.

If two prefix arguments (\\[universal-argument] \\[universal-argument]) are given when called interactively,
or if `igrep-read-multiple-files' is set, FILES is read from the minibuffer
multiple times.

If three prefix arguments (\\[universal-argument] \\[universal-argument] \\[universal-argument]) are given when called interactively,
or if `igrep-read-options' and `igrep-read-multiple-files' are set,
OPTIONS is read and FILES is read multiple times.

If `igrep-find' is non-nil, the directory or directories
containing FILES is recursively searched for files whose name matches
the file name component of FILES (and whose contents match
EXPRESSION)." t nil)

(autoload 'igrep-define "igrep" "\
Define ANALOGUE-COMMAND as an `igrep' analogue command.
Optional (VARIABLE VALUE) arguments specify temporary bindings for the command." nil 'macro)

(autoload 'igrep-find "igrep" "\
*Run `grep` via `find`; see \\[igrep] and `igrep-find'.
All arguments (including prefix arguments, when called interactively)
are handled by `igrep'." t nil)

(autoload 'igrep-find-define "igrep" "\
Define ANALOGUE-COMMAND-find as an `igrep' analogue `find` command.
Optional (VARIABLE VALUE) arguments specify temporary bindings for the command." nil 'macro)

(autoload 'dired-do-igrep "igrep" "\
*Run `grep` PROGRAM to match EXPRESSION (with optional OPTIONS)
on the marked (or next prefix ARG) files." t nil)

(autoload 'dired-do-igrep-find "igrep" "\
*Run `grep` PROGRAM to match EXPRESSION (with optional OPTIONS)
on the marked (or next prefix ARG) directories." t nil)

;;;***

(provide 'igrep-autoloads)
